# easybmp

`easybmp` is a python library for reading and writing BMP images. It is designed to be easy to use and provides a simple interface for reading and writing BMP files.

[GitHub Repo](https://github.com/NaoCoding/easybmp)

[Doc (GitHub Wiki)](https://github.com/NaoCoding/easybmp/wiki)

[PyPI](https://pypi.org/project/easybmp)

## 📦 Installion

```bash
pip install easybmp
```

## 📖 Usage

easybmp provides two different ways to use the library: using in python script or using command line interface.

## Examples

```bash
> easybmp -f test.bmp -s
> 
========================================
            BMP FILE INFO           
========================================
bfType        : BM
bfSize        : 54,462
bfReserved1   : 0
bfReserved2   : 0
bfOffBits     : 54
biSize        : 40
biWidth       : 100
biHeight      : 100
biPlanes      : 1
biBitCount    : 24
biCompression : 0
biSizeImage   : 0
========================================
```

